From 5e36656aea7ad402ace4d1af1cf2383d21cea41c Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Fri, 2 Jul 2021 23:33:24 +0200
Subject: [PATCH] Fix typos in pgstat.c, reorderbuffer.c and pathnodes.h

Author: Daniel Gustafsson
Reviewed-by: ..
Discussion: ..
---
 src/backend/postmaster/pgstat.c                 | 6 +++---
 src/backend/replication/logical/reorderbuffer.c | 2 +-
 src/include/nodes/pathnodes.h                   | 2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/backend/postmaster/pgstat.c b/src/backend/postmaster/pgstat.c
index ce8888cc30..11702f2a80 100644
--- a/src/backend/postmaster/pgstat.c
+++ b/src/backend/postmaster/pgstat.c
@@ -134,7 +134,7 @@ PgStat_MsgWal WalStats;
 /*
  * WAL usage counters saved from pgWALUsage at the previous call to
  * pgstat_send_wal(). This is used to calculate how much WAL usage
- * happens between pgstat_send_wal() calls, by substracting
+ * happens between pgstat_send_wal() calls, by subtracting
  * the previous counters from the current ones.
  */
 static WalUsage prevWalUsage;
@@ -2929,7 +2929,7 @@ pgstat_initialize(void)
 {
 	/*
 	 * Initialize prevWalUsage with pgWalUsage so that pgstat_send_wal() can
-	 * calculate how much pgWalUsage counters are increased by substracting
+	 * calculate how much pgWalUsage counters are increased by subtracting
 	 * prevWalUsage from pgWalUsage.
 	 */
 	prevWalUsage = pgWalUsage;
@@ -3105,7 +3105,7 @@ pgstat_send_wal(bool force)
 
 		/*
 		 * Calculate how much WAL usage counters were increased by
-		 * substracting the previous counters from the current ones. Fill the
+		 * subtracting the previous counters from the current ones. Fill the
 		 * results in WAL stats message.
 		 */
 		MemSet(&walusage, 0, sizeof(WalUsage));
diff --git a/src/backend/replication/logical/reorderbuffer.c b/src/backend/replication/logical/reorderbuffer.c
index b8c5e2a44e..1b4f4a528a 100644
--- a/src/backend/replication/logical/reorderbuffer.c
+++ b/src/backend/replication/logical/reorderbuffer.c
@@ -1545,7 +1545,7 @@ ReorderBufferCleanupTXN(ReorderBuffer *rb, ReorderBufferTXN *txn)
  * streaming or decoding them at PREPARE. Keep the remaining info -
  * transactions, tuplecids, invalidations and snapshots.
  *
- * We additionaly remove tuplecids after decoding the transaction at prepare
+ * We additionally remove tuplecids after decoding the transaction at prepare
  * time as we only need to perform invalidation at rollback or commit prepared.
  *
  * 'txn_prepared' indicates that we have decoded the transaction at prepare
diff --git a/src/include/nodes/pathnodes.h b/src/include/nodes/pathnodes.h
index b7b2817a5d..bebf774818 100644
--- a/src/include/nodes/pathnodes.h
+++ b/src/include/nodes/pathnodes.h
@@ -1350,7 +1350,7 @@ typedef struct TidPath
 } TidPath;
 
 /*
- * TidRangePath represents a scan by a continguous range of TIDs
+ * TidRangePath represents a scan by a contiguous range of TIDs
  *
  * tidrangequals is an implicitly AND'ed list of qual expressions of the form
  * "CTID relop pseudoconstant", where relop is one of >,>=,<,<=.
-- 
2.30.1 (Apple Git-130)

